@@ -61,7 +61,7 @@ class Arguments(object):
                             action='store_true',
                             default=False,
                             dest='breakpoint',
-                            help=Color.s('Set software breakpoint ({C}INT3{W}) before shellcode (default: {G}false{W})'))
+                            help=Color.s('Set software breakpoint ({G}INT3{W}) before shellcode (default: {G}false{W})'))
 
         custom.add_argument('--bad-chars',
                             action='store',
@@ -70,6 +70,12 @@ class Arguments(object):
                             type=str,
                             help=Color.s('List of bad chars to highlight (ex: {G}\\x00\\x0a{W}, default: {G}\\0x00{W})'))
 
+        custom.add_argument('--remove',
+                            action='store_true',
+                            default=False,
+                            dest='remove',
+                            help=Color.s('Remove bad chars from final binary executable (EXE, ELF and Mach-O). (default: {G}false{W})'))
+
         custom.add_argument('--cave-size',
                             action='store',
                             dest='cave_size',
@@ -105,6 +111,6 @@ class Arguments(object):
                             default=0,
                             dest='verbose',
                             help=Color.s(
-                                'Shows more options ({C}-h -v{W}). Prints commands and outputs. (default: {G}quiet{W})'))
+                                'Shows more options ({G}-h -v{W}). Prints commands and outputs. (default: {G}quiet{W})'))
 
 
